//##################################################################################################
//
//  Ceetron Desktop Components
//  Component: UnstructGrid
//  
//  --------------------------------------------------------------------------------------------
//  Copyright (C) 2011, Ceetron AS
//  This is UNPUBLISHED PROPRIETARY SOURCE CODE of Ceetron AS. The contents of this file may 
//  not be disclosed to third parties, copied or duplicated in any form, in whole or in part,
//  without the prior written permission of Ceetron AS.
//##################################################################################################

#pragma once

#include "CeeUnstructGrid/Base.h"
#include "CeeCore/Str.h"

namespace cee {
namespace ug {


//==================================================================================================
//
// 
//
//==================================================================================================
class CEE_UG_EXPORT Error
{
public:
    /// Available error codes
    enum Code
    {
        ERR_NOT_SET,                    ///< %Error not set
        ERR_ABORTED_BY_USER,            ///< Aborted by user
        ERR_INCONSISTENT_DATA,          ///< Inconsistent data
        ERR_USER_DEFINED_MESSAGE,       ///< A user defined message

        ERR_FILE_NOT_FOUND,             ///< File not found
        ERR_FILE_OPEN,                  ///< %Error opening file
        ERR_FILE_READ,                  ///< %Error reading file
        ERR_FILE_UNSUPPORTED_FILE_TYPE, ///< Unsupported file type. E.g. Not a VTF file
        ERR_FILE_INVALID_FORMAT,        ///< Internal errors in the file. File does not comply to the file specification
        ERR_VTFX_WRONG_PASSWORD         ///< Wrong password for VTFx file
    };

public:
    Error();

    Code        errorCode() const;
    void        setErrorCode(Code errorCode);
    Str         userDefinedErrorMessage() const;
    void        setUserDefinedError(const Str& errorMessage);

    static void safeSetErrorCode(Error* errorObj, Code errorCode);
    static void safeSetUserDefinedError(Error* errorObj, const Str& errorMessage);

private:
    Code    m_errorCode;
    Str     m_userDefinedErrorMessage;
};

}  // namespace ug
}  // namespace cee

